@@ -3,11 +3,10 @@
 import os
 
 from flask import Flask
-from flaskext.bcrypt import Bcrypt
 from jinja2 import Environment, FileSystemLoader, ChoiceLoader, PackageLoader
 import stripe
 
-from .bull import bull, mail, login_manager
+from .bull import bull, mail, login_manager, bcrypt
 from .models import Product, Purchase, db
 
 
@@ -22,8 +21,8 @@ app.jinja_loader = ChoiceLoader([
 stripe.api_key = app.config['STRIPE_SECRET_KEY']
 db.init_app(app)
 mail.init_app(app)
-bcrypt = Bcrypt(app)
+bcrypt.init_app(app)
 login_manager.init_app(app)
 app.register_blueprint(bull)
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
